==> ArabicOcr2EnglishTranslator-0.9.3.tar.gz: ArabicOcr2EnglishTranslator-0.9.3/arabic_ocr_translator/arabic_ocr_ar_en.py <==
#pypi #OCR Arabic2English Translator
#lib import
#!pip install easyocr
#!pip install transformers
import cv2
import matplotlib.pyplot as plt
import easyocr
from transformers import AutoModelWithLMHead, AutoTokenizer
from transformers import pipeline
model = AutoModelWithLMHead.from_pretrained("Helsinki-NLP/opus-mt-ar-en")
tokenizer = AutoTokenizer.from_pretrained("Helsinki-NLP/opus-mt-ar-en")
translation = pipeline("translation_ar_to_en", model=model, tokenizer=tokenizer)
reader = easyocr.Reader(['ar']) # finally import the EasyOCR reader language. English is used in this example.
#image_path='1.jpg'
#contents_ocr_file='contents_ocr.txt'
#translated_file='contents_translated.txt'
def arabic_ocr_english_translator(image_path,contents_ocr_file,translated_file):

    image = cv2.imread(image_path, 0)
    # display it
    plt.figure(figsize=(10,10))
    plt.axis('off')
    plt.imshow(image, cmap='Greys_r')
    easyresult = reader.readtext(image)
    with open (contents_ocr_file,'w',encoding='utf-8')as myfile:
        for i in range(len(easyresult)):
            print(easyresult[i][1])

        #with open ('character.txt','w',encoding='utf-8')as myfile:
            myfile.write(str(easyresult[i][1]))
    with open(contents_ocr_file) as f:
        contents = f.read()
        #print(contents)

    text = contents
    translated_text = translation(text, max_length=400)[0]['translation_text']
    with open (translated_file,'w')as tfile:
        for i in range(len(translated_text)):
            print(translated_text[i][1])
            tfile.write(str(translated_text[i][1]))
            

    return translated_text

==> ArabicOcr2EnglishTranslator-0.9.4.tar.gz: ArabicOcr2EnglishTranslator-0.9.4/arabic_ocr_translator/arabic_ocr_ar_en.py <==
#pypi #OCR Arabic2English Translator
#lib import
#!pip install easyocr
#!pip install transformers
import cv2
import matplotlib.pyplot as plt
import easyocr
from transformers import AutoModelWithLMHead, AutoTokenizer
from transformers import pipeline
model = AutoModelWithLMHead.from_pretrained("Helsinki-NLP/opus-mt-ar-en")
tokenizer = AutoTokenizer.from_pretrained("Helsinki-NLP/opus-mt-ar-en")
translation = pipeline("translation_ar_to_en", model=model, tokenizer=tokenizer)
reader = easyocr.Reader(['ar']) # finally import the EasyOCR reader language. English is used in this example.
#image_path='1.jpg'
contents_ocr_file='contents_ocr.txt'
translated_file='contents_translated.txt'
def arabic_ocr_english_translator(image_path):

    image = cv2.imread(image_path, 0)
    # display it
    plt.figure(figsize=(10,10))
    plt.axis('off')
    plt.imshow(image, cmap='Greys_r')
    easyresult = reader.readtext(image)
    with open (contents_ocr_file,'w',encoding='utf-8')as myfile:
        for i in range(len(easyresult)):
            print(easyresult[i][1])

        #with open ('character.txt','w',encoding='utf-8')as myfile:
            myfile.write(str(easyresult[i][1]))
    with open(contents_ocr_file) as f:
        contents = f.read()
        #print(contents)

    text = contents
    translated_text = translation(text, max_length=400)[0]['translation_text']
    with open (translated_file,'w')as tfile:
        for i in range(len(translated_text)):
            print(translated_text[i][1])
            tfile.write(str(translated_text[i][1]))
            

    return translated_text
